==> jc-1.4.0.tar.gz: polyglot/util/UnicodeWriter.h <==
// public class polyglot.util.UnicodeWriter

// class file dependencies
// @dep_class a4c6ebbb4edda7cb java_io_FilterWriter
// @dep_class 4897ee169f60a14f java_io_Writer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fb6b7201b85f5416 polyglot_util_UnicodeWriter

// header file dependencies
// @dep_header java_io_FilterWriter

#include "java/io/FilterWriter.h"

#ifndef _JC_polyglot_util_UnicodeWriter_H_
#define _JC_polyglot_util_UnicodeWriter_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_util_UnicodeWriter$sub_refs	_jc_polyglot_util_UnicodeWriter$sub_refs;
typedef struct _jc_polyglot_util_UnicodeWriter$sub_nonrefs	_jc_polyglot_util_UnicodeWriter$sub_nonrefs;
typedef struct _jc_polyglot_util_UnicodeWriter$refs	_jc_polyglot_util_UnicodeWriter$refs;
typedef struct _jc_polyglot_util_UnicodeWriter$nonrefs	_jc_polyglot_util_UnicodeWriter$nonrefs;
typedef struct _jc_polyglot_util_UnicodeWriter$object	_jc_polyglot_util_UnicodeWriter$object;

typedef const struct _jc_polyglot_util_UnicodeWriter$vmethods	_jc_polyglot_util_UnicodeWriter$vmethods;
typedef const struct _jc_polyglot_util_UnicodeWriter$vtable	_jc_polyglot_util_UnicodeWriter$vtable;
typedef const struct _jc_polyglot_util_UnicodeWriter$vtype	_jc_polyglot_util_UnicodeWriter$vtype;

// Constructors
extern void _jc_polyglot_util_UnicodeWriter$method$_init$514f7e161933236e(_jc_env *, struct _jc_polyglot_util_UnicodeWriter$object *, struct _jc_java_io_Writer$object *);

// Virtual methods
extern void _jc_polyglot_util_UnicodeWriter$method$write$6377ac6964854eb2(_jc_env *, struct _jc_polyglot_util_UnicodeWriter$object *, jint);
extern void _jc_polyglot_util_UnicodeWriter$method$write$4cff879bd9d86786(_jc_env *, struct _jc_polyglot_util_UnicodeWriter$object *, struct _jc_java_lang_String$object *, jint, jint);
extern void _jc_polyglot_util_UnicodeWriter$method$write$dc4877c8c0adbc0a(_jc_env *, struct _jc_polyglot_util_UnicodeWriter$object *, struct _jc_char_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_UnicodeWriter$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_polyglot_util_UnicodeWriter$method_info$write$4cff879bd9d86786;
extern _jc_method _jc_polyglot_util_UnicodeWriter$method_info$write$dc4877c8c0adbc0a;

// Virtual methods structure
struct _jc_polyglot_util_UnicodeWriter$vmethods {
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_polyglot_util_UnicodeWriter$object *, jint);
	void	(*write$4cff879bd9d86786)(_jc_env *, struct _jc_polyglot_util_UnicodeWriter$object *, struct _jc_java_lang_String$object *, jint, jint);
	void	(*write$dc4877c8c0adbc0a)(_jc_env *, struct _jc_polyglot_util_UnicodeWriter$object *, struct _jc_char_array *, jint, jint);
};

// Vtable
struct _jc_polyglot_util_UnicodeWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Writer$vmethods	java_io_Writer;
	_jc_java_io_FilterWriter$vmethods	java_io_FilterWriter;
	_jc_polyglot_util_UnicodeWriter$vmethods	polyglot_util_UnicodeWriter;
};

// Vtype
struct _jc_polyglot_util_UnicodeWriter$vtype {
	_jc_type			type;
	_jc_polyglot_util_UnicodeWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_UnicodeWriter$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_UnicodeWriter$refs {
    _jc_polyglot_util_UnicodeWriter$sub_refs	polyglot_util_UnicodeWriter;
    _jc_java_io_FilterWriter$sub_refs	java_io_FilterWriter;
    _jc_java_io_Writer$sub_refs	java_io_Writer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_UnicodeWriter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_UnicodeWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Writer$sub_nonrefs	java_io_Writer;
    _jc_java_io_FilterWriter$sub_nonrefs	java_io_FilterWriter;
    _jc_polyglot_util_UnicodeWriter$sub_nonrefs	polyglot_util_UnicodeWriter;
};

// Object instance structure
struct _jc_polyglot_util_UnicodeWriter$object {
	_jc_polyglot_util_UnicodeWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_UnicodeWriter$vtype	*vtype;
	_jc_polyglot_util_UnicodeWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_UnicodeWriter$vtype _jc_polyglot_util_UnicodeWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_UnicodeWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_UnicodeWriter$class_object;

#endif	/* _JC_polyglot_util_UnicodeWriter_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/UnicodeWriter.h <==
// public class polyglot.util.UnicodeWriter

// class file dependencies
// @dep_class a4c6ebbb4edda7cb java_io_FilterWriter
// @dep_class 4897ee169f60a14f java_io_Writer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fb6b7201b85f5416 polyglot_util_UnicodeWriter

// header file dependencies
// @dep_header java_io_FilterWriter

#include "java/io/FilterWriter.h"

#ifndef _JC_polyglot_util_UnicodeWriter_H_
#define _JC_polyglot_util_UnicodeWriter_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_util_UnicodeWriter$sub_refs	_jc_polyglot_util_UnicodeWriter$sub_refs;
typedef struct _jc_polyglot_util_UnicodeWriter$sub_nonrefs	_jc_polyglot_util_UnicodeWriter$sub_nonrefs;
typedef struct _jc_polyglot_util_UnicodeWriter$refs	_jc_polyglot_util_UnicodeWriter$refs;
typedef struct _jc_polyglot_util_UnicodeWriter$nonrefs	_jc_polyglot_util_UnicodeWriter$nonrefs;
typedef struct _jc_polyglot_util_UnicodeWriter$object	_jc_polyglot_util_UnicodeWriter$object;

typedef const struct _jc_polyglot_util_UnicodeWriter$vmethods	_jc_polyglot_util_UnicodeWriter$vmethods;
typedef const struct _jc_polyglot_util_UnicodeWriter$vtable	_jc_polyglot_util_UnicodeWriter$vtable;
typedef const struct _jc_polyglot_util_UnicodeWriter$vtype	_jc_polyglot_util_UnicodeWriter$vtype;

// Constructors
extern void _jc_polyglot_util_UnicodeWriter$method$_init$514f7e161933236e(_jc_env *, struct _jc_polyglot_util_UnicodeWriter$object *, struct _jc_java_io_Writer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_polyglot_util_UnicodeWriter$method$write$6377ac6964854eb2(_jc_env *, struct _jc_polyglot_util_UnicodeWriter$object *, jint) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_UnicodeWriter$method$write$4cff879bd9d86786(_jc_env *, struct _jc_polyglot_util_UnicodeWriter$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_UnicodeWriter$method$write$dc4877c8c0adbc0a(_jc_env *, struct _jc_polyglot_util_UnicodeWriter$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_UnicodeWriter$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_polyglot_util_UnicodeWriter$method_info$write$4cff879bd9d86786;
extern _jc_method _jc_polyglot_util_UnicodeWriter$method_info$write$dc4877c8c0adbc0a;

// Virtual methods structure
struct _jc_polyglot_util_UnicodeWriter$vmethods {
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_polyglot_util_UnicodeWriter$object *, jint) _JC_JCNI_ATTR;
	void	(*write$4cff879bd9d86786)(_jc_env *, struct _jc_polyglot_util_UnicodeWriter$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
	void	(*write$dc4877c8c0adbc0a)(_jc_env *, struct _jc_polyglot_util_UnicodeWriter$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_UnicodeWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Writer$vmethods	java_io_Writer;
	_jc_java_io_FilterWriter$vmethods	java_io_FilterWriter;
	_jc_polyglot_util_UnicodeWriter$vmethods	polyglot_util_UnicodeWriter;
};

// Vtype
struct _jc_polyglot_util_UnicodeWriter$vtype {
	_jc_type			type;
	_jc_polyglot_util_UnicodeWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_UnicodeWriter$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_UnicodeWriter$refs {
    _jc_polyglot_util_UnicodeWriter$sub_refs	polyglot_util_UnicodeWriter;
    _jc_java_io_FilterWriter$sub_refs	java_io_FilterWriter;
    _jc_java_io_Writer$sub_refs	java_io_Writer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_UnicodeWriter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_UnicodeWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Writer$sub_nonrefs	java_io_Writer;
    _jc_java_io_FilterWriter$sub_nonrefs	java_io_FilterWriter;
    _jc_polyglot_util_UnicodeWriter$sub_nonrefs	polyglot_util_UnicodeWriter;
};

// Object instance structure
struct _jc_polyglot_util_UnicodeWriter$object {
	_jc_polyglot_util_UnicodeWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_UnicodeWriter$vtype	*vtype;
	_jc_polyglot_util_UnicodeWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_UnicodeWriter$vtype _jc_polyglot_util_UnicodeWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_UnicodeWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_UnicodeWriter$class_object;

#endif	/* _JC_polyglot_util_UnicodeWriter_H_ */
